<?php
/**
 * Kapa functions and definitions
 * @package Kapa
 */


/**
 * Shorthand contents for theme assets url
 */
define('KAPA_VERSION', time());
define('KAPA_THEME_URI', get_template_directory_uri());
define('KAPA_THEME_DIR', get_template_directory());
define('KAPA_IMG',KAPA_THEME_URI . '/assets/img');
define('KAPA_CSS',KAPA_THEME_URI . '/assets/css');
define('KAPA_JS',KAPA_THEME_URI . '/assets/js');
if( !defined('KAPA_FRAMEWORK_VAR') ) define('KAPA_FRAMEWORK_VAR', 'kapa_opt');

/**
 * Sets up theme defaults and registers support for various WordPress features.
*/
if ( ! function_exists( 'kapa_setup' ) ) :

	function kapa_setup() {

		// Make theme available for translation.
		load_theme_textdomain( 'kapa', KAPA_THEME_DIR. '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// Let WordPress manage the document title.
		add_theme_support( 'title-tag' );

		// Enable support for Post Thumbnails on posts and pages.
		add_theme_support( 'post-thumbnails' );

		// Kapa custom image size
		add_image_size( 'kapa_standard_card', 860, 650, true );

		// Switch default core markup for search form, comment form, and comments
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		remove_theme_support( 'widgets-block-editor' );
	}
endif;
add_action( 'after_setup_theme', 'kapa_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
*/
function kapa_content_width() {
	// This variable is intended to be overruled from themes.
	$GLOBALS['content_width'] = apply_filters( 'kapa_content_width', 640 );
}
add_action( 'after_setup_theme', 'kapa_content_width', 0 );

/**
 * Enqueue scripts and styles.
 */
require KAPA_THEME_DIR . '/inc/enqueue.php';

if ( ! function_exists( 'kapa_fonts' ) ) {
	function kapa_fonts() {
		wp_enqueue_style( 'kapa-fonts', "//fonts.googleapis.com/css?family=Spartan:100,200,300,400,500,600,700,800,900|Oswald:200,300,400,500,600,700", '', '1.0.0', 'screen' );
	}
}
add_action( 'wp_enqueue_scripts', 'kapa_fonts' );

/**
 * Custom template tags for this theme.
 */
require KAPA_THEME_DIR. '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require KAPA_THEME_DIR. '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require KAPA_THEME_DIR. '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require KAPA_THEME_DIR. '/inc/jetpack.php';
}

/**
 * Load bootstrap navwalker 
 */
require KAPA_THEME_DIR. '/inc/bootstrap-navwalker.php';

/**
 * Load theme widgets
 */
require KAPA_THEME_DIR. '/inc/widget.php';

/**
 * Custom style
 */
require KAPA_THEME_DIR. '/inc/custom-style.php';

/**
 * Social link
*/
require KAPA_THEME_DIR. '/inc/social-link.php';

/**
 * Recommended plugin
*/
require KAPA_THEME_DIR. '/lib/recommended-plugin.php';

/**
 * Theme's filters and actions
*/
require KAPA_THEME_DIR . '/inc/filter_actions.php';

// Load WooCommerce compatibility file.
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}


/**
 * Admin dashboard style and scripts
 */
add_action( 'admin_enqueue_scripts', function() {
    global $pagenow;
    wp_enqueue_script( 'kapa-admin', get_template_directory_uri() . '/assets/js/kapa-admin.js', array('jquery'), '1.0.0', true );
    if ( $pagenow == 'admin.php' ) {
		wp_enqueue_style( 'kapa-admin-dashboard', get_template_directory_uri() . '/assets/css/admin-dashboard.min.css' );
    }
});

/**
 * Notice dismiss handle
 */
add_action( 'admin_init', function() {
    if ( isset($_GET['dismissed']) && $_GET['dismissed'] == 1 ) {
        update_option('notice_dismissed', '1');
    }
});