<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Kapa
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function kapa_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'article-sidebar' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'kapa_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function kapa_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'kapa_pingback_header' );

 /*
 * Pagination
 */
if ( ! function_exists( 'kapa_pagination' ) ) :
    function kapa_pagination() {
		global $wp_query;
		if ( $wp_query->max_num_pages <= 1 ) {
			return;
		}
    ?>
        <div class="pagination-area text-center">
			<div class="nav-links">
				<?php echo paginate_links( array(
					'format' => '?paged=%#%',
					'prev_text' => '<i class="ri-arrow-left-line"></i>',
					'next_text' => '<i class="ri-arrow-right-line"></i>',
					)
				) ?>
			</div>
		</div>
    <?php
    }
endif;

/**
 * If page edited by elementor
 */
if ( ! function_exists( 'kapa_is_elementor' ) ) :
	function kapa_is_elementor(){
		if ( function_exists( 'elementor_fail_php_version' ) ):
			global $post;
			if( $post != '' ):
				return \Elementor\Plugin::$instance->documents->get( $post->ID )->is_built_with_elementor();
			endif;
		endif;
	}
endif;

/**
 * Kapa Mobile Logo
*/
if ( ! function_exists( 'mobile_logo' ) ) :
	function mobile_logo() {
		global $kapa_opt;
		// kapa Logo
		if ( isset( $kapa_opt['mobile_logo']['url']) && $kapa_opt['mobile_logo']['url'] !='' ) :
			$kapa_logo = $kapa_opt['mobile_logo']['url'];
		else :
			$kapa_logo = 'null';
		endif;
		?>
			<?php if ( $kapa_logo != 'null' ) : ?>
				<img src="<?php echo esc_url($kapa_logo); ?>" alt="<?php bloginfo( 'name' ); ?>">
			<?php else : ?>
				<h2 class="optional-title"><?php bloginfo( 'name' ); ?></h2> 
			<?php endif; ?>
		<?php
	}
endif;

/**
 * Kapa Main Logo
*/
if ( ! function_exists( 'main_logo' ) ) :
	function main_logo(){
		global $kapa_opt;
		// kapa Logo
		if ( isset( $kapa_opt['main_logo']['url'] ) && $kapa_opt['main_logo']['url'] !='' ) :
			$main_logo = $kapa_opt['main_logo']['url'];
		else :
			$main_logo = 'null';
		endif;
		?>
			<?php if ( $main_logo != 'null' ) : ?>
				<img src="<?php echo esc_url( $main_logo ); ?>" alt="<?php bloginfo( 'name' ); ?>">
			<?php else : ?>
				<h2 class="optional-title"><?php bloginfo( 'name' ); ?></h2> 
			<?php endif; ?>
		<?php
	}
endif;
/**
 * Kapa Main Logo 2
*/
if ( ! function_exists( 'main_logo2' ) ) :
	function main_logo2(){
		global $kapa_opt;
		// kapa Logo
		if ( isset( $kapa_opt['main_logo2']['url'] ) && $kapa_opt['main_logo2']['url'] !='' ) :
			$main_logo2 = $kapa_opt['main_logo2']['url'];
		else :
			$main_logo2 = 'null';
		endif;
		?>
			<?php if ( $main_logo2 != 'null' ) : ?>
				<img src="<?php echo esc_url( $main_logo2 ); ?>" alt="<?php bloginfo( 'name' ); ?>">
			<?php else : ?>
				<h2 class="optional-title"><?php bloginfo( 'name' ); ?></h2> 
			<?php endif; ?>
		<?php
	}
endif;
/**
 * Kapa Main Logo 3
*/
if ( ! function_exists( 'main_logo3' ) ) :
	function main_logo3(){
		global $kapa_opt;
		// kapa Logo
		if ( isset( $kapa_opt['main_logo3']['url'] ) && $kapa_opt['main_logo3']['url'] !='' ) :
			$main_logo3 = $kapa_opt['main_logo3']['url'];
		else :
			$main_logo3 = 'null';
		endif;
		?>
			<?php if ( $main_logo3 != 'null' ) : ?>
				<img src="<?php echo esc_url( $main_logo3 ); ?>" alt="<?php bloginfo( 'name' ); ?>">
			<?php else : ?>
				<h2 class="optional-title"><?php bloginfo( 'name' ); ?></h2> 
			<?php endif; ?>
		<?php
	}
endif;

/**
 * Kapa Footer Logo
 */
if ( ! function_exists( 'footer_logo' ) ) :
	function footer_logo(){
		global $kapa_opt;
		// kapa Logo
		if ( isset( $kapa_opt['footer_logo']['url']) && $kapa_opt['footer_logo']['url'] !='' ) :
			$kapa_logo = $kapa_opt['footer_logo']['url'];
		else :
			$kapa_logo = 'null';
		endif;
		?>
			<?php if ( $kapa_logo != 'null' ) : ?>
				<img src="<?php echo esc_url( $kapa_logo ); ?>" alt="<?php bloginfo( 'name' ); ?>"><?php
			else : ?>
				<h2 class="footer-logo-title"><?php bloginfo( 'name' ); ?></h2> <?php  
			endif; ?>
		<?php
	}
endif;

/**
 * Estimated Reading Time
 */
if ( ! function_exists( 'kapa_reading_time' ) ) :
	function kapa_reading_time() {
		global $post;
		$thecontent  = get_post_field( 'post_content', $post->ID );
		$words 		 = str_word_count( strip_tags( $thecontent ) );
		$readingtime = ceil( $words / 200 );
		$output 	 = $readingtime;
		return $output;
	}
endif;


/**
 * Kapa RTL
*/
if( ! function_exists( 'kapa_rtl' ) ):
	function kapa_rtl() {
		global $kapa_opt;

		if(	isset( $kapa_opt['kapa_enable_rtl'])  ):
			$kapa_rtl_opt = $kapa_opt['kapa_enable_rtl'];
		else:
			$kapa_rtl_opt = 'disable';
		endif;

		if ( isset( $_GET['rtl'] ) ) {
			$kapa_rtl_opt = $_GET['rtl'];
		}

		if ( $kapa_rtl_opt == 'enable' ) :
			$kapa_rtl = true;
		else:
			$kapa_rtl = false;
		endif;

		return $kapa_rtl;
	}
endif;