<?php
/**
 *  Kapa WooCommerce functions and definitions
 */
 	// Theme WooCommerce Support
	add_theme_support( 'woocommerce', apply_filters( 'storefront_woocommerce_args', array(
		'single_image_width'    => 530,
		'thumbnail_image_width' => 350,
		add_theme_support( 'wc-product-gallery-zoom' ),
		add_theme_support( 'wc-product-gallery-lightbox' ),
		add_theme_support( 'wc-product-gallery-slider' ),
	) ) );

	if ( is_active_sidebar( 'shop' ) ) {
		// Change number or products per row to 3
		add_filter('loop_shop_columns', 'kapa_loop_columns', 999);
		if (!function_exists('kapa_loop_columns')) {
			function kapa_loop_columns() {
				global $kapa_opt;

				$product_sidebar = isset( $kapa_opt['product_sidebar']) ? $kapa_opt['product_sidebar'] : '';

				if ( isset( $_GET['shop-sidebar'] ) ):
					if( $_GET['shop-sidebar'] == 'right' || $_GET['shop-sidebar'] == 'left' ):
						return 2; // 2 products per row
					elseif( $_GET['shop-sidebar'] == 'none' ):
						return 3; // 3 products per row
					endif;
				else:
					if ($product_sidebar == 'kapa_product_no_sidebar' ):
						return 3; // 3 products per row
					elseif ( $product_sidebar == 'left-sidebar' || $product_sidebar == 'right-sidebar' ):
						return 2; // 2 products per row
					else:
						return 3; // 2 products per row
					endif;
				endif;	
			}
		}
	}else{
		// Change number or products per row to 3
		add_filter('loop_shop_columns', 'kapa_loop_columns', 999);
		if (!function_exists('kapa_loop_columns')) {
			function kapa_loop_columns() {
				return 3; // 3 products per row
			}
		}
	}

	// Change number of related products output
	function kapa_woo_related_products_limit() {
		global $product;
		$args['posts_per_page'] = 6;
		return $args;
	}
	add_filter( 'woocommerce_output_related_products_args', 'kapa_related_products_args', 20 );
	function kapa_related_products_args( $args ) {
		global $kapa_opt;

		if( isset( $kapa_opt['kapa_related_product_count'] ) ):
		   $count = $kapa_opt['kapa_related_product_count'];
		else:
		   $count = '3';
		endif;

		$args['posts_per_page'] = $count; // related products
		
		global $kapa_opt;
		$product_sidebar = isset( $kapa_opt['product_sidebar']) ? $kapa_opt['product_sidebar'] : '';
		
		if ( isset( $_GET['shop-sidebar'] ) ):
			if( $_GET['shop-sidebar'] == 'right' || $_GET['shop-sidebar'] == 'left' ):
				$args['columns'] = 2; // 2 products per row
			elseif( $_GET['shop-sidebar'] == 'none' ):
				$args['columns'] = 3; // 3 products per row
			endif;
		else:

			if ( $product_sidebar == 'kapa_product_no_sidebar' ):
				$args['columns'] = 3; // 3 products per row
			elseif ( $product_sidebar == 'left-sidebar' || $product_sidebar == 'right-sidebar' ):
				$args['columns'] = 2; // 3 products per row
			else:
				$args['columns'] = 3; // 3 products per row
			endif;
		endif;
		
		return $args;
	}

	// Filter woocommerce_checkout_fields
	if ( ! function_exists( 'kapa_field_class_add' ) ) :
		function kapa_field_class_add($fields) {
		foreach ($fields as &$fieldset) {
			foreach ($fieldset as &$field) {
				$field['class'][] = 'form-group'; 
				$field['input_class'][] = 'form-control';
			}
		}
		return $fields;
	}
	endif;
	add_filter('woocommerce_checkout_fields', 'kapa_field_class_add' );

	/**
	 * Post Per page
	 */
	add_filter( 'loop_shop_per_page', 'kapa_redefine_products_per_page', 9999 );
	
	function kapa_redefine_products_per_page( $per_page ) {
		global $kapa_opt;

		if( isset( $kapa_opt['products_page_count'] ) ):
		   $count = $kapa_opt['products_page_count'];
		else:
		   $count = '6';
		endif;
		
		$per_page = $count;
		return $per_page;
	}

	if ( ! function_exists( 'kapa_wc_refresh_mini_cart_count' ) ) :
		function kapa_wc_refresh_mini_cart_count($fragments){
	
			$cart_number = WC()->cart->get_cart_contents_count();
			ob_start();
			?>
			<span class="mini-cart-count">
				<?php echo esc_html(WC()->cart->get_cart_contents_count()); ?>
			</span>
			<?php
				$fragments['.mini-cart-count'] = ob_get_clean();
			return $fragments;
		}
	endif;
	add_filter( 'woocommerce_add_to_cart_fragments', 'kapa_wc_refresh_mini_cart_count');
	
	// Enqueue JavaScript for AJAX
	function kapa_enqueue_custom_scripts() {
		wp_enqueue_script( 'custom-ajax-script', get_template_directory_uri() . '/assets/js/custom-ajax-script.js', array( 'jquery' ), '1.0', true );
		wp_localize_script( 'custom-ajax-script', 'customAjax', array(
			'ajaxUrl' => admin_url( 'admin-ajax.php' ),
			'nonce'   => wp_create_nonce( 'custom-ajax-nonce' ),
		) );
	}
	add_action( 'wp_enqueue_scripts', 'kapa_enqueue_custom_scripts' );
	
	// Update mini-cart count using AJAX
	function kapa_update_mini_cart_count() {
		check_ajax_referer( 'custom-ajax-nonce', 'security' );
	
		$count = WC()->cart->get_cart_contents_count();
	
		wp_send_json( $count );
	}
	add_action( 'wp_ajax_kapa_update_mini_cart_count', 'kapa_update_mini_cart_count' );
	add_action( 'wp_ajax_nopriv_kapa_update_mini_cart_count', 'kapa_update_mini_cart_count' );
	
	// Update mini-cart count in the header
	function kapa_custom_mini_cart_count() {
		$count = WC()->cart->get_cart_contents_count();
		?>
		<span class="mini-cart-count"><?php echo esc_html( $count ); ?></span>
		<?php
	}
	
	// Update mini-cart count via AJAX after cart update
	function kapa_update_mini_cart_count_after_update() {
		ob_start();
		kapa_custom_mini_cart_count();
		$mini_cart_count = ob_get_clean();
		wp_send_json_success( $mini_cart_count );
	}
	add_action( 'wp_ajax_kapa_update_mini_cart_count_after_update', 'kapa_update_mini_cart_count_after_update' );
	add_action( 'wp_ajax_nopriv_kapa_update_mini_cart_count_after_update', 'kapa_update_mini_cart_count_after_update' );