<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to kapa/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 8.6.0
 */

defined( 'ABSPATH' ) || exit;

get_header( 'shop' );

global $kapa_opt;

/**
 * Hook: woocommerce_before_main_content.
 *
 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
 * @hooked woocommerce_breadcrumb - 20
 * @hooked WC_Structured_Data::generate_website_data() - 30
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );

do_action( 'woocommerce_before_main_content' );

$post_page_id       = get_option( 'woocommerce_shop_page_id' );
$product_sidebar    = isset( $kapa_opt['product_sidebar']) ? $kapa_opt['product_sidebar'] : '';

if( $product_sidebar == 'kapa_product_no_sidebar' && is_active_sidebar( 'shop' ) ):
    $div_class = "col-lg-4 col-sm-6";
elseif( $product_sidebar == 'right-sidebar' && is_active_sidebar( 'shop' ) ):
    $div_class = "col-lg-6 col-sm-6";
elseif( $product_sidebar == 'left-sidebar' && is_active_sidebar( 'shop' ) ):
    $div_class = "col-lg-6 col-sm-6";
elseif( $product_sidebar == 'kapa_product_no_sidebar' ):
    $div_class = "col-lg-3 col-sm-6";
else :
    $div_class = "col-lg-6 col-sm-6 col-md-6";
endif;

if( function_exists('acf_add_options_page') ) {
	$hide_banner 		= get_field( 'enable_page_banner', $post_page_id);
	$hide_breadcrumb 	= get_field( 'hide_breadcrumb' , $post_page_id);
}else {
	$hide_banner 		= false;
	$hide_breadcrumb 	= false;
}

if( $hide_banner == false ) {
    $page_spac = 'mt-80';
} else {
    $page_spac = '';
}

$banner_bg = isset( $kapa_opt['shop_bg']['url']) ? $kapa_opt['shop_bg']['url'] : '';
?> 

<?php if( $hide_banner == false ) { ?>
    <div class="page-banner-area" style="background-image:url(<?php echo esc_url( $banner_bg ); ?>);">
		<div class="container">
            <?php if ( apply_filters( 'woocommerce_show_page_title', true ) ) : ?>
                <div class="page-banner-content">
                    <?php if( $hide_breadcrumb == false ) : ?>
                        <ul>
                            <li>
                                <a href="<?php echo esc_url( home_url( '/' ) ); ?>">
                                    <?php esc_html_e('Home', 'kapa')?>
                                </a>
                            </li>
                            <li><?php woocommerce_page_title(); ?></li>
                        </ul>
                    <?php endif; ?>

                    <?php if(  get_field( 'page_banner_title' , $post_page_id) != '' ) { ?>
                        <h2><?php echo esc_html( get_field( 'page_banner_title' , $post_page_id ) ); ?></h2>
                    <?php } else { ?>
                        <h2> <?php woocommerce_page_title(); ?> </h2>
                    <?php } ?>
                </div>
            <?php endif; ?>
		</div>
	</div>
<?php } ?>
  
<div class="special-products-area pt-100 pb-100 <?php echo esc_attr( $page_spac ); ?>">
    <div class="container">
        <div class="row">
        <?php
            if ( is_active_sidebar( 'shop' ) ) {
                if ( isset( $_GET['shop'] ) ) {
                    $kapa_shop_cat_sidebar = $_GET['shop'];
                    if ( $kapa_shop_cat_sidebar == 'none' ): ?>
                        <div class="col-lg-12 col-md-12">
                    <?php elseif ( $kapa_shop_cat_sidebar == 'left' ): ?>
                        <?php do_action( 'woocommerce_sidebar' ); ?>
                        <div class="col-lg-8 col-md-12">
                    <?php elseif ( $kapa_shop_cat_sidebar == 'right' ): ?>
                        <div class="col-lg-8 col-md-12">
                    <?php endif;

                } else {
                    if( $product_sidebar == 'left-sidebar' ): ?>
                        <?php do_action( 'woocommerce_sidebar' ); ?>
                        <div class="col-lg-8 col-md-12">
                    <?php elseif ( $product_sidebar == 'right-sidebar' ): ?>
                        <?php do_action( 'woocommerce_sidebar' ); ?>
                        <div class="col-lg-8 col-md-12">
                    <?php elseif ( $product_sidebar == 'kapa_product_no_sidebar' ): ?>
                        <div class="col-lg-12 col-md-12">
                    <?php else: ?>
                        <?php do_action( 'woocommerce_sidebar' ); ?>
                        <div class="col-lg-8 col-md-12">
                    <?php endif;
                }
            } else { ?>
                <div class="col-lg-12 col-md-12">
            <?php } ?>
                <?php if ( woocommerce_product_loop() ) { ?>

                    <div class="woocommerce-topbar">
                        <?php do_action( 'woocommerce_before_shop_loop' ); ?>
                    </div>

                    <?Php
                    woocommerce_product_loop_start();

                    if ( wc_get_loop_prop( 'total' ) ) {
                        while ( have_posts() ) {
                            the_post();

                            /**
                             * Hook: woocommerce_shop_loop.
                             *
                             * @hooked WC_Structured_Data::generate_product_data() - 10
                             */
                            do_action( 'woocommerce_shop_loop' );?>

                            <div class="<?php echo esc_attr( $div_class ); ?>">
                                <?php wc_get_template_part( 'content', 'product' ); ?>
                            </div><?php
                        }
                    }

                    woocommerce_product_loop_end();

                    /**
                     * Hook: woocommerce_after_shop_loop.
                     *
                     * @hooked woocommerce_pagination - 10
                     */
                    do_action( 'woocommerce_after_shop_loop' );
                } else {
                    /**
                     * Hook: woocommerce_no_products_found.
                     *
                     * @hooked wc_no_products_found - 10
                     */
                    do_action( 'woocommerce_no_products_found' );
                } ?>
            </div> <!-- end clo-8 -->
            
            <?php 
            if ( isset( $_GET['shop'] ) ) {
                if ( $kapa_shop_cat_sidebar == 'right' ) { 
                    do_action( 'woocommerce_sidebar' );
                }
            } else {
                if ( $product_sidebar == 'right-sidebar' ) { 
                    do_action( 'woocommerce_sidebar' );
                }
            } ?>
        </div>
    </div>
</div>
<?php
/**
 * Hook: woocommerce_after_main_content.
 *
 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
 */
do_action( 'woocommerce_after_main_content' );

/**
 * Hook: woocommerce_sidebar.
 *
 * @hooked woocommerce_get_sidebar - 10
 */

get_footer( 'shop' ); ?>