<?php
/**
 * The Template for displaying all single products
 *
 * This template can be overridden by copying it to kapa/woocommerce/single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @package 	WooCommerce/Templates
 * @version     1.6.4
 */
global $kapa_opt;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

get_header( 'shop' );

if( function_exists('acf_add_options_page') ) {
	$hide_banner 		= get_field( 'enable_page_banner' );
	$hide_breadcrumb 	= get_field( 'hide_breadcrumb' );
}else {
	$hide_banner 		= false;
	$hide_breadcrumb 	= false;
}

if( $hide_banner == false ){
    $page_spac = 'mt-80';
} else {
    $page_spac = '';
}

$product_sidebar    = isset( $kapa_opt['product_sidebar']) ? $kapa_opt['product_sidebar'] : '';

if( function_exists('acf_add_options_page') ) {
	$banner_bg = get_field( 'post_banner_background_image' );
}else {
    $banner_bg = '';
}


remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );
?>

<?php if( $hide_banner == false ) { ?>
    <div class="page-banner-area" style="background-image:url(<?php echo esc_url( $banner_bg ); ?>);">
        <div class="container-fluid">
            <div class="page-banner-content">
                <?php if( $hide_breadcrumb == false ) : ?>
                    <ul>
                        <li>
                            <a href="<?php echo esc_url( home_url( '/' ) ); ?>">
                                <?php esc_html_e('Home', 'kapa')?>
                            </a>
                        </li>
                        <li><?php the_title(); ?></li>
                    </ul>
                <?php endif; ?>

                <?php if(  get_field( 'page_banner_title') != '' ) { ?>
                    <h2><?php echo esc_html( get_field( 'page_banner_title' ) ); ?></h2>
                <?php } else { ?>
                    <h2><?php the_title(); ?></h2>
                <?php } ?>
            </div>
        </div>
    </div>
<?php } ?>

<div class="products_details ptb-100 <?php echo esc_attr( $page_spac ); ?>">
    <div class="container">
        <div class="row">                
            <?php if ( is_active_sidebar( 'shop' ) ): ?>
                <?php if ( isset( $_GET['shop'] ) ): ?>
                    <?php  $kapa_shop_cat_sidebar = $_GET['shop']; ?>
                    <?php if ( $kapa_shop_cat_sidebar == 'none' ): ?>
                        <div class="col-lg-12 col-md-12">
                    <?php elseif ( $kapa_shop_cat_sidebar == 'left' ): ?>
                        <?php do_action( 'woocommerce_sidebar' ); ?>
                        <div class="col-lg-8 col-md-12">
                    <?php elseif ( $kapa_shop_cat_sidebar == 'right' ): ?>
                        <div class="col-lg-8 col-md-12">
                    <?php endif; ?>
                <?php else: ?>
                    <?php if( $product_sidebar == 'left-sidebar' ): ?>
                        <?php do_action( 'woocommerce_sidebar' ); ?>
                        <div class="col-lg-8 col-md-12">
                    <?php elseif ( $product_sidebar == 'right-sidebar' ): ?>
                        <div class="col-lg-8 col-md-12">
                    <?php else: ?>
                        <div class="col-lg-12 col-md-12">
                    <?php endif; ?>
                <?php endif; ?>
            <?php else: ?>
                <div class="col-lg-12 col-md-12">
            <?php endif; ?>

                <?php
                /**
                 * woocommerce_before_main_content hook.
                 *
                 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
                 * @hooked woocommerce_breadcrumb - 20
                 */

                do_action( 'woocommerce_before_main_content' );

                    while ( have_posts() ) : the_post();

                        wc_get_template_part( 'content', 'single-product' );

                    endwhile;

                    /**
                     * woocommerce_after_main_content hook.
                     *
                     * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
                     */
                    do_action( 'woocommerce_after_main_content' );
                ?>
            </div>
            <?php 
            if ( isset( $_GET['shop'] ) ):
                if ( $kapa_shop_cat_sidebar == 'right' ) :
                    do_action( 'woocommerce_sidebar' );
                endif; 
            else:
                if ( $product_sidebar == 'right-sidebar' ):
                    do_action( 'woocommerce_sidebar' );
                endif; 
            endif; 
            ?>
        </div>
    </div>
</div>

<?php get_footer( 'shop' );
/* Omit closing PHP tag at the end of PHP files to avoid "headers already sent" issues. */
?>
           
